@@ -3,7 +3,7 @@
 begin
   require 'rbconfig'
 rescue LoadError
-  # for make mjit-headers
+  # for make rjit-headers
 end
 
 # Namespace for file utility methods for copying, moving, removing, etc.
@@ -180,7 +180,7 @@ end
 # - {CVE-2004-0452}[https://cve.mitre.org/cgi-bin/cvename.cgi?name=CAN-2004-0452].
 #
 module FileUtils
-  VERSION = "1.7.0"
+  VERSION = "1.7.2"
 
   def self.private_module_function(name)   #:nodoc:
     module_function name
@@ -192,8 +192,6 @@ module FileUtils
   #
   #   FileUtils.pwd # => "/rdoc/fileutils"
   #
-  # FileUtils.getwd is an alias for FileUtils.pwd.
-  #
   # Related: FileUtils.cd.
   #
   def pwd
@@ -235,8 +233,6 @@ module FileUtils
   #     cd ..
   #     cd fileutils
   #
-  # FileUtils.chdir is an alias for FileUtils.cd.
-  #
   # Related: FileUtils.pwd.
   #
   def cd(dir, verbose: nil, &block) # :yield: dir
@@ -515,8 +511,6 @@ module FileUtils
   # Raises an exception if +dest+ is the path to an existing file
   # and keyword argument +force+ is not +true+.
   #
-  # FileUtils#link is an alias for FileUtils#ln.
-  #
   # Related: FileUtils.link_entry (has different options).
   #
   def ln(src, dest, force: nil, noop: nil, verbose: nil)
@@ -707,8 +701,6 @@ module FileUtils
   #     ln -sf src2.txt dest2.txt
   #     ln -s srcdir3/src0.txt srcdir3/src1.txt destdir3
   #
-  # FileUtils.symlink is an alias for FileUtils.ln_s.
-  #
   # Related: FileUtils.ln_sf.
   #
   def ln_s(src, dest, force: nil, relative: false, target_directory: true, noop: nil, verbose: nil)
@@ -876,8 +868,6 @@ module FileUtils
   #
   # Raises an exception if +src+ is a directory.
   #
-  # FileUtils.copy is an alias for FileUtils.cp.
-  #
   # Related: {methods for copying}[rdoc-ref:FileUtils@Copying].
   #
   def cp(src, dest, preserve: nil, noop: nil, verbose: nil)
@@ -1164,8 +1154,6 @@ module FileUtils
   #     mv src0 dest0
   #     mv src1.txt src1 dest1
   #
-  # FileUtils.move is an alias for FileUtils.mv.
-  #
   def mv(src, dest, force: nil, noop: nil, verbose: nil, secure: nil)
     fu_output_message "mv#{force ? ' -f' : ''} #{[src,dest].flatten.join ' '}" if verbose
     return if noop
@@ -1223,8 +1211,6 @@ module FileUtils
   #
   #     rm src0.dat src0.txt
   #
-  # FileUtils.remove is an alias for FileUtils.rm.
-  #
   # Related: {methods for deleting}[rdoc-ref:FileUtils@Deleting].
   #
   def rm(list, force: nil, noop: nil, verbose: nil)
@@ -1250,8 +1236,6 @@ module FileUtils
   #
   # See FileUtils.rm for keyword arguments.
   #
-  # FileUtils.safe_unlink is an alias for FileUtils.rm_f.
-  #
   # Related: {methods for deleting}[rdoc-ref:FileUtils@Deleting].
   #
   def rm_f(list, noop: nil, verbose: nil)
@@ -1339,8 +1323,6 @@ module FileUtils
   #
   # See FileUtils.rm_r for keyword arguments.
   #
-  # FileUtils.rmtree is an alias for FileUtils.rm_rf.
-  #
   # Related: {methods for deleting}[rdoc-ref:FileUtils@Deleting].
   #
   def rm_rf(list, noop: nil, verbose: nil, secure: nil)
@@ -1642,7 +1624,13 @@ module FileUtils
       st = File.stat(s)
       unless File.exist?(d) and compare_file(s, d)
         remove_file d, true
-        copy_file s, d
+        if d.end_with?('/')
+          mkdir_p d
+          copy_file s, d + File.basename(s)
+        else
+          mkdir_p File.expand_path('..', d)
+          copy_file s, d
+        end
         File.utime st.atime, st.mtime, d if preserve
         File.chmod fu_mode(mode, st), d if mode
         File.chown uid, gid, d if uid or gid
