@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("3.3.") or
-    raise "ruby lib version (3.3.5) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (3.3.7) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.3/riscv64-openbsd")
@@ -21,9 +21,9 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
   CONFIG["MINOR"] = "3"
-  CONFIG["TEENY"] = "5"
-  CONFIG["PATCHLEVEL"] = "100"
-  CONFIG["INSTALL"] = '/local/pobj/ruby-3.3.5/bin/install -c'
+  CONFIG["TEENY"] = "7"
+  CONFIG["PATCHLEVEL"] = "123"
+  CONFIG["INSTALL"] = '/local/pobj/ruby-3.3.7/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)33"
@@ -45,7 +45,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--enable-shared' '--program-suffix=33' '--with-soname=ruby33' '--with-ruby-version=3.3' '--with-mantype=doc' '--with-setjmp-type=_setjmp' '--enable-pthread' '--enable-ipv6' '--without-baseruby' '--without-bundled-libffi' '--disable-option-checking' '--with-compress-debug-sections=no' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CXX=c++' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXXFLAGS=-O2 -pipe'"
+  CONFIG["configure_args"] = " '--with-coroutine=riscv64' '--enable-shared' '--program-suffix=33' '--with-soname=ruby33' '--with-ruby-version=3.3' '--with-mantype=doc' '--with-setjmp-type=_setjmp' '--enable-pthread' '--enable-ipv6' '--without-baseruby' '--without-bundled-libffi' '--disable-option-checking' '--with-compress-debug-sections=no' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info' '--localstatedir=/var' '--disable-silent-rules' '--disable-gtk-doc' 'CC=cc' 'CXX=c++' 'CFLAGS=-O2 -pipe' 'LDFLAGS=-L/usr/local/lib' 'CPPFLAGS=-DOPENSSL_NO_STATIC_ENGINE -I/usr/local/include' 'CXXFLAGS=-O2 -pipe'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -73,7 +73,7 @@ module RbConfig
   CONFIG["MAKEFILES"] = "Makefile"
   CONFIG["USE_LLVM_WINDRES"] = ""
   CONFIG["PLATFORM_DIR"] = ""
-  CONFIG["COROUTINE_TYPE"] = "pthread"
+  CONFIG["COROUTINE_TYPE"] = "riscv64"
   CONFIG["THREAD_MODEL"] = "pthread"
   CONFIG["SYMBOL_PREFIX"] = ""
   CONFIG["EXPORT_PREFIX"] = ""
@@ -160,9 +160,9 @@ module RbConfig
   CONFIG["DOXYGEN"] = ""
   CONFIG["DOT"] = ""
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/local/pobj/ruby-3.3.5/bin/install -c -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/local/pobj/ruby-3.3.5/bin/install -c -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/local/pobj/ruby-3.3.5/bin/install -c -s -m 755"
+  CONFIG["INSTALL_DATA"] = "/local/pobj/ruby-3.3.7/bin/install -c -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/local/pobj/ruby-3.3.7/bin/install -c -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/local/pobj/ruby-3.3.7/bin/install -c -s -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["DLLWRAP"] = ""
