@@ -1,9 +1,10 @@
 # frozen_string_literal: true
-require 'rubygems/command'
-require 'rubygems/version_option'
-require 'rubygems/security_option'
-require 'rubygems/remote_fetcher'
-require 'rubygems/package'
+
+require_relative "../command"
+require_relative "../version_option"
+require_relative "../security_option"
+require_relative "../remote_fetcher"
+require_relative "../package"
 
 # forward-declare
 
@@ -17,18 +18,18 @@ class Gem::Commands::UnpackCommand < Gem::Command
   include Gem::SecurityOption
 
   def initialize
-    require 'fileutils'
+    require "fileutils"
 
-    super 'unpack', 'Unpack an installed gem to the current directory',
-          :version => Gem::Requirement.default,
-          :target  => Dir.pwd
+    super "unpack", "Unpack an installed gem to the current directory",
+          version: Gem::Requirement.default,
+          target: Dir.pwd
 
-    add_option('--target=DIR',
-               'target directory for unpacking') do |value, options|
+    add_option("--target=DIR",
+               "target directory for unpacking") do |value, options|
       options[:target] = value
     end
 
-    add_option('--spec', 'unpack the gem specification') do |value, options|
+    add_option("--spec", "unpack the gem specification") do |_value, options|
       options[:spec] = true
     end
 
@@ -95,19 +96,17 @@ command help for an example.
 
         FileUtils.mkdir_p @options[:target] if @options[:target]
 
-        destination = begin
-          if @options[:target]
-            File.join @options[:target], spec_file
-          else
-            spec_file
-          end
+        destination = if @options[:target]
+          File.join @options[:target], spec_file
+        else
+          spec_file
         end
 
-        File.open destination, 'w' do |io|
+        File.open destination, "w" do |io|
           io.write metadata
         end
       else
-        basename = File.basename path, '.gem'
+        basename = File.basename path, ".gem"
         target_dir = File.expand_path basename, options[:target]
 
         package = Gem::Package.new path, security_policy
@@ -131,7 +130,7 @@ command help for an example.
       return this_path if File.exist? this_path
     end
 
-    return nil
+    nil
   end
 
   ##
@@ -152,16 +151,16 @@ command help for an example.
   # source directories?
 
   def get_path(dependency)
-    return dependency.name if dependency.name =~ /\.gem$/i
+    return dependency.name if /\.gem$/i.match?(dependency.name)
 
     specs = dependency.matching_specs
 
-    selected = specs.max_by {|s| s.version }
+    selected = specs.max_by(&:version)
 
     return Gem::RemoteFetcher.fetcher.download_to_cache(dependency) unless
       selected
 
-    return unless dependency.name =~ /^#{selected.name}$/i
+    return unless /^#{selected.name}$/i.match?(dependency.name)
 
     # We expect to find (basename).gem in the 'cache' directory.  Furthermore,
     # the name match must be exact (ignoring case).
