@@ -43,12 +43,12 @@ class Gem::Ext::ExtConfBuilder < Gem::Ext::Builder
 
       full_tmp_dest = File.join(extension_dir, tmp_dest_relative)
 
-      # TODO remove in RubyGems 4
+      # TODO: remove in RubyGems 4
       if Gem.install_extension_in_lib && lib_dir
         FileUtils.mkdir_p lib_dir
         entries = Dir.entries(full_tmp_dest) - %w[. ..]
         entries = entries.map {|entry| File.join full_tmp_dest, entry }
-        FileUtils.cp_r entries, lib_dir, :remove_destination => true
+        FileUtils.cp_r entries, lib_dir, remove_destination: true
       end
 
       FileUtils::Entry_.new(full_tmp_dest).traverse do |ent|
@@ -65,8 +65,6 @@ class Gem::Ext::ExtConfBuilder < Gem::Ext::Builder
     FileUtils.rm_rf tmp_dest if tmp_dest
   end
 
-  private
-
   def self.get_relative_path(path, base)
     path[0..base.length - 1] = "." if path.start_with?(base)
     path
